@@ -20,7 +20,7 @@ class ClusterRole(Resource):
         super().__init__(**kwargs)
         self.rules = rules
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
         if not self.yaml_file:
             if not self.rules:
